@@ -1,6 +1,7 @@
 from patchwork.steps.AgenticLLM.AgenticLLM import AgenticLLM
 from patchwork.steps.AgenticLLMV2.AgenticLLMV2 import AgenticLLMV2
 from patchwork.steps.AnalyzeImpact.AnalyzeImpact import AnalyzeImpact
+from patchwork.steps.BrowserUse.BrowserUse import BrowserUse
 from patchwork.steps.CallAPI.CallAPI import CallAPI
 from patchwork.steps.CallCode2Prompt.CallCode2Prompt import CallCode2Prompt
 from patchwork.steps.CallLLM.CallLLM import CallLLM
@@ -26,13 +27,10 @@ from patchwork.steps.ExtractPackageManagerFile.ExtractPackageManagerFile import
 )
 from patchwork.steps.FilterBySimilarity.FilterBySimilarity import FilterBySimilarity
 from patchwork.steps.FixIssue.FixIssue import FixIssue
-from patchwork.steps.GenerateCodeRepositoryEmbeddings.GenerateCodeRepositoryEmbeddings import (
-    GenerateCodeRepositoryEmbeddings,
-)
-from patchwork.steps.GenerateEmbeddings.GenerateEmbeddings import GenerateEmbeddings
 from patchwork.steps.GetTypescriptTypeInfo.GetTypescriptTypeInfo import (
     GetTypescriptTypeInfo,
 )
+from patchwork.steps.GitHubAgent.GitHubAgent import GitHubAgent
 from patchwork.steps.JoinList.JoinList import JoinList
 from patchwork.steps.LLM.LLM import LLM
 from patchwork.steps.ModifyCode.ModifyCode import ModifyCode
@@ -40,7 +38,6 @@ from patchwork.steps.ModifyCodeOnce.ModifyCodeOnce import ModifyCodeOnce
 from patchwork.steps.PR.PR import PR
 from patchwork.steps.PreparePR.PreparePR import PreparePR
 from patchwork.steps.PreparePrompt.PreparePrompt import PreparePrompt
-from patchwork.steps.QueryEmbeddings.QueryEmbeddings import QueryEmbeddings
 from patchwork.steps.ReadEmail.ReadEmail import ReadEmail
 from patchwork.steps.ReadFile.ReadFile import ReadFile
 from patchwork.steps.ReadIssues.ReadIssues import ReadIssues
@@ -84,8 +81,6 @@ __all__ = [
     "ExtractPackageManagerFile",
     "FilterBySimilarity",
     "FixIssue",
-    "GenerateCodeRepositoryEmbeddings",
-    "GenerateEmbeddings",
     "LLM",
     "ModifyCode",
     "ModifyCodePB",
@@ -94,7 +89,6 @@ __all__ = [
     "PreparePR",
     "PreparePrompt",
     "PRPB",
-    "QueryEmbeddings",
     "ReadEmail",
     "ReadFile",
     "ReadIssues",
@@ -104,6 +98,7 @@ __all__ = [
     "ScanDepscan",
     "ScanSemgrep",
     "ScanSonar",
+    "GitHubAgent",
     "SendEmail",
     "SimplifiedLLM",
     "SimplifiedLLMOnce",
@@ -112,4 +107,5 @@ __all__ = [
     "JoinList",
     "JoinListPB",
     "GetTypescriptTypeInfo",
+    "BrowserUse",
 ]
